Module responses

Module responses 

RPC method response types.

These types appear as the result field of a crate::jsonrpc::JsonRpcSuccessResponse.

MethodResponse type
SendMessageSendMessageResponse
ListTasksTaskListResponse
GetExtendedAgentCardAgentCard (re-exported as AuthenticatedExtendedCardResponse)

Structs

ListPushConfigsResponse
The result of a ListTaskPushNotificationConfigs call.
TaskListResponse
The result of a ListTasks call: a page of tasks with pagination.

Enums

SendMessageResponse
The result of a SendMessage call: either a completed Task or an immediate Message response.

Type Aliases

AuthenticatedExtendedCardResponse
The full (private) agent card returned by agent/authenticatedExtendedCard.